# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Type3Enum(object):

    """Implementation of the 'Type3' enum.

    The object type.

    Attributes:
        USER: The enum member of type str.

    """
    _all_values = ['user']
    USER = 'user'

    @classmethod
    def validate(cls, value):
        """Validates value contains in enum

        Args:
            value: the value to be validated

        Returns:
            boolean : if value is valid enum values.

        """
        return value in cls._all_values
   