# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ItemType3Enum(object):

    """Implementation of the 'Item Type3' enum.

    The ID type: either `artist` or `user`.

    Attributes:
        ARTIST: The enum member of type str.
        USER: The enum member of type str.

    """
    ARTIST = 'artist'

    USER = 'user'

