# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Type5Enum(object):

    """Implementation of the 'Type5' enum.

    The object type.

    Attributes:
        AUDIO_FEATURES: The enum member of type str.

    """
    AUDIO_FEATURES = 'audio_features'

