# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ReasonEnum(object):

    """Implementation of the 'Reason' enum.

    The reason for the restriction. Albums may be restricted if the content is
    not available in a given market, to the user's subscription type, or when
    the user's account is set to not play explicit content.
    Additional reasons may be added in the future.

    Attributes:
        MARKET: The enum member of type str.
        PRODUCT: The enum member of type str.
        EXPLICIT: The enum member of type str.

    """
    _all_values = ['market', 'product', 'explicit']
    MARKET = 'market'

    PRODUCT = 'product'

    EXPLICIT = 'explicit'

    @classmethod
    def validate(cls, value):
        """Validates value contains in enum

        Args:
            value: the value to be validated

        Returns:
            boolean : if value is valid enum values.

        """
        return value in cls._all_values
   