# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AlbumTypeEnum(object):

    """Implementation of the 'AlbumType' enum.

    The type of the album.

    Attributes:
        ALBUM: The enum member of type str.
        SINGLE: The enum member of type str.
        COMPILATION: The enum member of type str.

    """
    _all_values = ['album', 'single', 'compilation']
    ALBUM = 'album'

    SINGLE = 'single'

    COMPILATION = 'compilation'

    @classmethod
    def validate(cls, value):
        """Validates value contains in enum

        Args:
            value: the value to be validated

        Returns:
            boolean : if value is valid enum values.

        """
        return value in cls._all_values
   