# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ItemType1Enum(object):

    """Implementation of the 'Item Type1' enum.

    The ID type: currently only `artist` is supported.

    Attributes:
        ARTIST: The enum member of type str.

    """
    _all_values = ['artist']
    ARTIST = 'artist'

    @classmethod
    def validate(cls, value):
        """Validates value contains in enum

        Args:
            value: the value to be validated

        Returns:
            boolean : if value is valid enum values.

        """
        return value in cls._all_values
   