# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OAuthScopeEnum(object):

    """Implementation of the 'OAuth Scope' enum.

    OAuth 2 scopes supported by the API

    Attributes:
        APP-REMOTE-CONTROL: Communicate with the Spotify app on your device. 
        PLAYLIST-READ-PRIVATE: Access your private playlists. 
        PLAYLIST-READ-COLLABORATIVE: Access your collaborative playlists. 
        PLAYLIST-MODIFY-PUBLIC: Manage your public playlists. 
        PLAYLIST-MODIFY-PRIVATE: Manage your private playlists. 
        USER-LIBRARY-READ: Access your saved content. 
        USER-LIBRARY-MODIFY: Manage your saved content. 
        USER-READ-PRIVATE: Access your subscription details. 
        USER-READ-EMAIL: Get your real email address. 
        USER-FOLLOW-READ: Access your followers and who you are following. 
        USER-FOLLOW-MODIFY: Manage your saved content. 
        USER-TOP-READ: Read your top artists and content. 
        USER-READ-PLAYBACK-POSITION: Read your position in content you have
            played. 
        USER-READ-PLAYBACK-STATE: Read your currently playing content and
            Spotify Connect devices information. 
        USER-READ-RECENTLY-PLAYED: Access your recently played items. 
        USER-READ-CURRENTLY-PLAYING: Read your currently playing content. 
        USER-MODIFY-PLAYBACK-STATE: Control playback on your Spotify clients
            and Spotify Connect devices. 
        UGC-IMAGE-UPLOAD: Upload images to Spotify on your behalf. 
        STREAMING: Play content and control playback on your other devices. 

    """
    APP_REMOTE_CONTROL = 'app-remote-control'

    PLAYLIST_READ_PRIVATE = 'playlist-read-private'

    PLAYLIST_READ_COLLABORATIVE = 'playlist-read-collaborative'

    PLAYLIST_MODIFY_PUBLIC = 'playlist-modify-public'

    PLAYLIST_MODIFY_PRIVATE = 'playlist-modify-private'

    USER_LIBRARY_READ = 'user-library-read'

    USER_LIBRARY_MODIFY = 'user-library-modify'

    USER_READ_PRIVATE = 'user-read-private'

    USER_READ_EMAIL = 'user-read-email'

    USER_FOLLOW_READ = 'user-follow-read'

    USER_FOLLOW_MODIFY = 'user-follow-modify'

    USER_TOP_READ = 'user-top-read'

    USER_READ_PLAYBACK_POSITION = 'user-read-playback-position'

    USER_READ_PLAYBACK_STATE = 'user-read-playback-state'

    USER_READ_RECENTLY_PLAYED = 'user-read-recently-played'

    USER_READ_CURRENTLY_PLAYING = 'user-read-currently-playing'

    USER_MODIFY_PLAYBACK_STATE = 'user-modify-playback-state'

    UGC_IMAGE_UPLOAD = 'ugc-image-upload'

    STREAMING = 'streaming'

