# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ModeEnum(object):

    """Implementation of the 'Mode' enum.

    Indicates the modality (major or minor) of a section, the type of scale
    from which its melodic content is derived. This field will contain a 0 for
    "minor", a 1 for "major", or a -1 for no result. Note that the major key
    (e.g. C major) could more likely be confused with the minor key at 3
    semitones lower (e.g. A minor) as both keys carry the same pitches.

    Attributes:
        ENUM_MINUS1: The enum member of type int.
        ENUM_0: The enum member of type int.
        ENUM_1: The enum member of type int.

    """
    ENUM_MINUS1 = -1

    ENUM_0 = 0

    ENUM_1 = 1

