# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AlbumGroupEnum(object):

    """Implementation of the 'AlbumGroup' enum.

    This field describes the relationship between the artist and the album.

    Attributes:
        ALBUM: The enum member of type str.
        SINGLE: The enum member of type str.
        COMPILATION: The enum member of type str.
        APPEARS_ON: The enum member of type str.

    """
    ALBUM = 'album'

    SINGLE = 'single'

    COMPILATION = 'compilation'

    APPEARS_ON = 'appears_on'

