# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ItemTypeEnum(object):

    """Implementation of the 'Item type' enum.

    Attributes:
        ALBUM: The enum member of type str.
        ARTIST: The enum member of type str.
        PLAYLIST: The enum member of type str.
        TRACK: The enum member of type str.
        SHOW: The enum member of type str.
        EPISODE: The enum member of type str.
        AUDIOBOOK: The enum member of type str.

    """
    ALBUM = 'album'

    ARTIST = 'artist'

    PLAYLIST = 'playlist'

    TRACK = 'track'

    SHOW = 'show'

    EPISODE = 'episode'

    AUDIOBOOK = 'audiobook'

