# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ReleaseDatePrecisionEnum(object):

    """Implementation of the 'ReleaseDatePrecision' enum.

    The precision with which `release_date` value is known.

    Attributes:
        YEAR: The enum member of type str.
        MONTH: The enum member of type str.
        DAY: The enum member of type str.

    """
    _all_values = ['year', 'month', 'day']
    YEAR = 'year'

    MONTH = 'month'

    DAY = 'day'

    @classmethod
    def validate(cls, value):
        """Validates value contains in enum

        Args:
            value: the value to be validated

        Returns:
            boolean : if value is valid enum values.

        """
        return value in cls._all_values
   