# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class IncludeExternalEnum(object):

    """Implementation of the 'Include External' enum.

    If `include_external=audio` is specified it signals that the client can
    play externally hosted audio content, and marks
    the content as playable in the response. By default externally hosted
    audio content is marked as unplayable in the response.

    Attributes:
        AUDIO: The enum member of type str.

    """
    AUDIO = 'audio'

